[PATCH 02/11] cli/insert: rename check_folder_name to is_valid_folder_name

Jani Nikula jani at nikula.org
Mon Sep 22 02:54:53 PDT 2014


An "is something" predicate conveys the meaning better. While at it,
improve the function documentation and error message. Besides the
error message change, no functional changes.
---
 notmuch-insert.c |   13 ++++++++-----
 1 files changed, 8 insertions(+), 5 deletions(-)

diff --git a/notmuch-insert.c b/notmuch-insert.c
index 8dfc8bb..770275b 100644
--- a/notmuch-insert.c
+++ b/notmuch-insert.c
@@ -83,10 +83,13 @@ sync_dir (const char *dir)
     return ret;
 }
 
 /* Check the specified folder name does not contain a directory
  * component ".." to prevent writes outside of the Maildir hierarchy. */
 static notmuch_bool_t
-check_folder_name (const char *folder)
+is_valid_folder_name (const char *folder)
 {
     const char *p = folder;
 
@@ -449,8 +452,8 @@ notmuch_insert_command (notmuch_config_t *config, int argc, char *argv[])
     if (folder == NULL) {
 	maildir = db_path;
     } else {
-	if (! check_folder_name (folder)) {
-	    fprintf (stderr, "Error: bad folder name: %s\n", folder);
+	if (! is_valid_folder_name (folder)) {
+	    fprintf (stderr, "Error: invalid folder name: '%s'\n", folder);
 	    return EXIT_FAILURE;
 	}
 	maildir = talloc_asprintf (config, "%s/%s", db_path, folder);
@@ -83,10 +83,13 @@ sync_dir (const char *dir)
 }
 
-/* Check the specified folder name does not contain a directory
- * component ".." to prevent writes outside of the Maildir hierarchy. */
+/*
+ * Check the specified folder name does not contain a directory
+ * component ".." to prevent writes outside of the Maildir
+ * hierarchy. Return TRUE on valid folder name, FALSE otherwise.
+ */
 static notmuch_bool_t
-- 
1.7.2.5



More information about the notmuch mailing list